C--------------------------------------------------------------------
C The user of the OPEN-ADAS system and data (hereinafter "the User")
C accepts the following terms and conditions: 
C 
C   1. The University of Strathclyde uses all reasonable endeavours
C      to ensure the accuracy of the data provided and any
C      information given, but the University makes no warranty,
C      expressed or implied as to its accuracy, integrity, fitness
C      for purpose and shall not be responsible for the use to
C      which the data is put by the User and/or any consequences
C      arising out of any inaccuracies or omissions.
C 
C   2. Any downloaded OPEN-ADAS file is made available here for the
C      personal use of the User only.  It must not be used for any
C      commercial application, incorporated into any web site or in
C      any form re-distributed without express prior written
C      permission from the ADAS Project. In particular, but not by
C      way of limitation, it must not be:
C 
C        * inserted into a managed database structure
C        * redistributed along with a modelling or analysis code
C        * made available on a public website.
C 
C Permission for OPEN-ADAS data incorporation in non-commercial
C code/system development for scientific advance will not be
C unreasonably withheld, but will be subject to written agreement
C on a case by case basis.
C 
C The User will indemnify the University of Strathclyde and keep
C it fully and effectively indemnified against each and every
C claim made against the University as a result of the User's
C use of the data.  
C--------------------------------------------------------------------
       PROGRAM TEST
       
       IMPLICIT NONE
C------------------------------------------------------------------------
C  Purpose:
C          Test the XXDATA_13 routine and also provide a brief
C          example of its use.
C
C  Explanaton:
C          This program is distributed as part of the ADAS
C          subroutine library either via direct CVS to ADAS Project
C          members or via download by OPEN-ADAS users. It reads a
C          file called "test.dat" (distributed along with this
C          program) and prints out some of the contents. The
C          program is intended to serve as an example of using the
C          XXDATA_13 subroutine as well as testing it. A short
C          shell script called "test.sh" is used to compile and
C          test the code.
C
C  Variables:
C          All variables are documented by XXDATA_13. See either the
C          Fortran source or the PDF documentation for the routine.
C          Variables not passed into XXDATA_13 are trivial in nature.
C
C  Routines:
C          Routine    Source    Brief description
C          -------------------------------------------------------------
C          XXDATA_13  ADAS      Read complete data from an ADF13 file
C
C  Author : Allan Whiteford
C
C  Date   : 11/01/08
C       
C-----------------------------------------------------------------------

C-----------------------------------------------------------------------
C     Parameters required by XXDATA_13
C     --------------------------------        
      INTEGER     NSTORE          , NTDIM         , NDDIM
      PARAMETER ( NSTORE   = 500  , NTDIM = 24    , NDDIM = 24 )
C-----------------------------------------------------------------------

C-----------------------------------------------------------------------
C     Input variables (i.e. non-parameter) required by XXDATA_13
C     ----------------------------------------------------------
      INTEGER      IUNIT
      CHARACTER*80 DSNAME     
C-----------------------------------------------------------------------		

C-----------------------------------------------------------------------
C     Output variables required by XXDATA_13
C     --------------------------------------
      CHARACTER*8         CFILE(NSTORE)
      CHARACTER*2         CINDM(NSTORE)
      CHARACTER*8         CTYPE(NSTORE)
      CHARACTER*10        CWAVEL(NSTORE)
      CHARACTER*2         ESYM
      INTEGER             IDA(NSTORE), ISELA(NSTORE)
      INTEGER             ITA(NSTORE), IZ,          IZ0
      INTEGER             IZ1,         NBSEL
      REAL*8              SXB(NTDIM,NDDIM,NSTORE),  TEDA(NDDIM,NSTORE)
      REAL*8              TETA(NTDIM,NSTORE)
C-----------------------------------------------------------------------

C-----------------------------------------------------------------------
C     Variables only used by this test program
C     ----------------------------------------
      INTEGER   I,J,K
      INTEGER   ISTORE
C----------------------------------------------------------------------

C-----------------------------------------------------------------------
C     Open input file for reading
C     ---------------------------      
      IUNIT = 10
      DSNAME='test.dat'
      OPEN(UNIT = IUNIT , FILE=DSNAME , STATUS = 'OLD')
C-----------------------------------------------------------------------
       
C-----------------------------------------------------------------------
C     Pass unit number and dimension parameters to XXDATA_13 and
C     get back contents of file.
C     --------------------------      

      CALL XXDATA_13( IUNIT  , DSNAME ,
     &                NSTORE , NTDIM  , NDDIM  ,
     &                IZ0    , IZ     , IZ1    , ESYM  ,
     &                NBSEL  , ISELA  ,
     &                CWAVEL , CFILE  , CTYPE  , CINDM ,
     &                ITA    , IDA    ,
     &                TETA   , TEDA   ,
     &                SXB
     &              )
C-----------------------------------------------------------------------
   
C-----------------------------------------------------------------------
C     Print out some of the contents to screen
C     ----------------------------------------      

       PRINT *,'XXDATA_13 Test Program'      
       PRINT *,'----------------------'
       PRINT *,' '
       PRINT *,'The following is some information about the'
       PRINT *,'input file: '//DSNAME
       PRINT *,' '       
       PRINT *,'All information below is for transition 10'
       PRINT *,' '       
       PRINT *,'Temperature Grid'
       PRINT *,(TETA(I,10),I=1,ITA(10))
       PRINT *,' '       
       PRINT *,'Density Grid'
       PRINT *,(TEDA(I,10),I=1,IDA(10))
       PRINT *,' '       
       PRINT *,'S/XB for 3rd density as a function of temperature'
       PRINT *,(SXB(I,3,10),I=1,ITA(10))
       PRINT *,' '       
       PRINT *,'S/XB for 5th temperature as a function of density'
       PRINT *,(SXB(5,I,10),I=1,IDA(10))
C-------------------------------------------------------------------

      END					  	
